@@ -22,14 +22,15 @@ class TestGetClient(unittest.TestCase):
 
         self.assertRaises(Exception, client.get_client, 'foo', 'bar')
 
-    @mock.patch('bigquery.client.SignedJwtAssertionCredentials')
+    @mock.patch('bigquery.client._credentials')
     @mock.patch('bigquery.client.build')
-    def test_initialize_readonly(self, mock_build, mock_cred):
+    def test_initialize_readonly(self, mock_build, mock_return_cred):
         """Ensure that a BigQueryClient is initialized and returned with
         read-only permissions.
         """
         from bigquery.client import BIGQUERY_SCOPE_READ_ONLY
 
+        mock_cred = mock.Mock()
         mock_http = mock.Mock()
         mock_cred.return_value.authorize.return_value = mock_http
         mock_bq = mock.Mock()
@@ -37,11 +38,13 @@ class TestGetClient(unittest.TestCase):
         key = 'key'
         service_account = 'account'
         project_id = 'project'
+        mock_return_cred.return_value = mock_cred
 
         bq_client = client.get_client(
             project_id, service_account=service_account, private_key=key,
             readonly=True)
 
+        mock_return_cred.assert_called_once_with()
         mock_cred.assert_called_once_with(service_account, key,
                                           scope=BIGQUERY_SCOPE_READ_ONLY)
         mock_cred.authorize.assert_called_once()
@@ -49,14 +52,15 @@ class TestGetClient(unittest.TestCase):
         self.assertEquals(mock_bq, bq_client.bigquery)
         self.assertEquals(project_id, bq_client.project_id)
 
-    @mock.patch('bigquery.client.SignedJwtAssertionCredentials')
+    @mock.patch('bigquery.client._credentials')
     @mock.patch('bigquery.client.build')
-    def test_initialize_read_write(self, mock_build, mock_cred):
+    def test_initialize_read_write(self, mock_build, mock_return_cred):
         """Ensure that a BigQueryClient is initialized and returned with
         read/write permissions.
         """
         from bigquery.client import BIGQUERY_SCOPE
 
+        mock_cred = mock.Mock()
         mock_http = mock.Mock()
         mock_cred.return_value.authorize.return_value = mock_http
         mock_bq = mock.Mock()
@@ -64,11 +68,13 @@ class TestGetClient(unittest.TestCase):
         key = 'key'
         service_account = 'account'
         project_id = 'project'
+        mock_return_cred.return_value = mock_cred
 
         bq_client = client.get_client(
             project_id, service_account=service_account, private_key=key,
             readonly=False)
 
+        mock_return_cred.assert_called_once_with()
         mock_cred.assert_called_once_with(service_account, key,
                                           scope=BIGQUERY_SCOPE)
         mock_cred.authorize.assert_called_once()
